%define anolis_release 3
%bcond_without autoconf

Summary: tool for simulating superuser privileges
Name: fakeroot
Version: 1.31
Release: %{anolis_release}%{?dist}
License: GPLv3+ and LGPLv2+ and (GPL+ or Artistic)
URL: https://tracker.debian.org/pkg/fakeroot
Source0: https://cdn-aws.deb.debian.org/debian/pool/main/f/fakeroot/%{name}_%{version}.orig.tar.gz
Patch1: fakeroot-multilib.patch
Patch2: relax_tartest.patch
BuildRequires: make gcc
%if %{with autoconf}
BuildRequires:  autoconf automake libtool po4a
%endif
BuildRequires: /usr/bin/getopt libacl-devel libcap-devel sharutils
Requires: /usr/bin/getopt
Requires: fakeroot-libs = %{version}-%{release}
Requires(post): /usr/sbin/alternatives
Requires(post): /usr/bin/readlink
Requires(preun): /usr/sbin/alternatives

%description
fakeroot runs a command in an environment where it appears to have root
privileges for file manipulation. This is useful for allowing users to
create archives (tar, ar, .deb etc.) with files in them with root
permissions/ownership. Without fakeroot one would have to have root
privileges to create the constituent files of the archives with the
correct permissions and ownership, and then pack them up, or one would
have to construct the archives directly, without using the archiver.

%package libs
Summary: tool for simulating superuser privileges (libraries)
Requires:       %{name} = %{EVR}

%description libs
This %{name}-libs package contains the libraries required by %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%if %{with autoconf}
./bootstrap
pushd doc
po4a -k 0 --rm-backups --variable "srcdir=../doc/" po4a/po4a.cfg
popd
%endif

for file in ./doc/{*.1,*/*.1}; do
  iconv -f latin1 -t utf8 < $file > $file.new && \
  mv -f $file.new $file
done

for type in sysv tcp; do
mkdir obj-$type
cd obj-$type
cat >> configure << 'EOF'
#!/bin/sh
exec ../configure "$@"
EOF
chmod +x configure
%configure \
  --disable-dependency-tracking --disable-static \
  --libdir=%{_libdir}/libfakeroot --with-ipc=$type \
  --program-suffix=-$type
make
cd ..
done

%install
for type in sysv tcp; do
  make -C obj-$type install libdir=%{_libdir}/libfakeroot DESTDIR=%{buildroot}
  mv %{buildroot}%{_libdir}/libfakeroot/libfakeroot-0.so \
     %{buildroot}%{_libdir}/libfakeroot/libfakeroot-$type.so
  rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.so
  rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.*la
  %find_lang faked-$type --without-mo --with-man
  %find_lang fakeroot-$type --without-mo --with-man
done

rm %{buildroot}%{_mandir}{,/*}/man1/fake{d,root}-sysv.1
rename -- -tcp '' %{buildroot}%{_mandir}{,/*}/man1/fake{d,root}-tcp.1
sed -e 's/-tcp//g' fake{d,root}-tcp.lang > fakeroot.lang

%check
for type in sysv tcp; do
  make -C obj-$type check VERBOSE=1
done

%generate_compatibility_deps

%post
link=$(readlink -e "/usr/bin/fakeroot")
if [ "$link" = "/usr/bin/fakeroot" ]; then
  rm -f /usr/bin/fakeroot
fi
link=$(readlink -e "%{_bindir}/faked")
if [ "$link" = "%{_bindir}/faked" ]; then
  rm -f "%{_bindir}/faked"
fi
link=$(readlink -e "%{_libdir}/libfakeroot/libfakeroot-0.so")
if [ "$link" = "%{_libdir}/libfakeroot/libfakeroot-0.so" ]; then
  rm -f "%{_libdir}/libfakeroot/libfakeroot-0.so"
fi

/usr/sbin/alternatives --install "%{_bindir}/fakeroot" fakeroot \
  "%{_bindir}/fakeroot-tcp" 50 \
  --slave %{_bindir}/faked faked %{_bindir}/faked-tcp \
  --slave %{_libdir}/libfakeroot/libfakeroot-0.so libfakeroot.so %{_libdir}/libfakeroot/libfakeroot-tcp.so \

/usr/sbin/alternatives --install "%{_bindir}/fakeroot" fakeroot \
  "%{_bindir}/fakeroot-sysv" 40 \
  --slave %{_bindir}/faked faked %{_bindir}/faked-sysv \
  --slave %{_libdir}/libfakeroot/libfakeroot-0.so libfakeroot.so %{_libdir}/libfakeroot/libfakeroot-sysv.so \

%preun
if [ $1 = 0 ]; then
  /usr/sbin/alternatives --remove fakeroot "%{_bindir}/fakeroot-tcp"
  /usr/sbin/alternatives --remove fakeroot "%{_bindir}/fakeroot-sysv"
fi

%files -f %{name}.lang
%license COPYING
%defattr(-,root,root,-)
%dir %{abidir}
%{_bindir}/faked-*
%ghost %{_bindir}/faked
%{_bindir}/fakeroot-*
%ghost %{_bindir}/fakeroot
%{_mandir}/man1/faked.1*
%{_mandir}/man1/fakeroot.1*

%files libs
%dir %{_libdir}/libfakeroot
%{_libdir}/libfakeroot/libfakeroot-sysv.so
%{_libdir}/libfakeroot/libfakeroot-tcp.so
%{abidir}/libfakeroot-sysv.dump
%{abidir}/libfakeroot-tcp.dump
%ghost %{_libdir}/libfakeroot/libfakeroot-0.so

%files doc
%doc AUTHORS DEBUG BUGS INSTALL ChangeLog README* NEWS doc/*

%changelog
* Tue Apr 11 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.31-3
- optimize spec

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.31-2
- Del Specific Fields

* Thu Feb 16 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.31-1
- update version and optimize spec

* Fri May 20 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.28-1
- init from upstream
